/**
 * Licensed to Jasig under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Jasig licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a
 * copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.jasig.portal.events;

import org.jasig.portal.portlet.rendering.worker.IPortletExecutionWorker;

/**
 * Used to signal that a portlet execution has hung
 * 
 * @author Eric Dalquist
 */
public class PortletHungEvent extends PortalEvent {
    private static final long serialVersionUID = 1L;
    
    private transient final IPortletExecutionWorker<?> worker;
    
    private final String fname;

    @SuppressWarnings("unused")
    private PortletHungEvent() {
        this.worker = null;
        this.fname = null;
    }

    PortletHungEvent(PortalEventBuilder eventBuilder, IPortletExecutionWorker<?> worker) {
        super(eventBuilder);
        
        this.worker = worker;
        this.fname = worker.getPortletFname();
    }
    
    /**
     * @return The portlet worker that is hung. Not available during event aggregation
     */
    public IPortletExecutionWorker<?> getWorker() {
        return worker;
    }

    /**
     * @return The functional name of the hung portlet
     */
    public String getFname() {
        return fname;
    }
    
    @Override
    public String toString() {
        return super.toString() + 
                ", fname=" + this.fname + "]";
    }
}
